@@ -4,13 +4,12 @@ optional @space handling.
 """
 
 import re
+import urllib
 
 from markdown import util, inlinepatterns
 from markdown.extensions.wikilinks import (WikiLinkExtension,
         WikiLinks)
 
-from tiddlyweb.web.util import encode_name
-
 FRONTBOUND = r'(?:^|(?<=[\s|\(]))'
 FREELINKB = FRONTBOUND + r'\[\[([^]]+?)\]\]'
 WIKILINKB = FRONTBOUND + r'(~?[A-Z][a-z]+[A-Z]\w+\b)'
@@ -131,3 +130,10 @@ class MarkdownLinks(WikiLinks):
 
 def makeExtension(configs=None):
     return MarkdownLinksExtension(configs=configs)
+
+def encode_name(name):
+    """
+    Like the encode_name found in tiddlyweb, but does not escape #.
+    """
+    return urllib.quote(name.encode('utf-8'), safe=".!~*'()#")
+
